[ci skip] Fix UseCooldownComponent jd (#11565)

This commit is contained in:
Noah 2024-11-09 23:24:56 +01:00
parent 89d6bc1a93
commit bbc8fc8fec

View file

@ -1701,6 +1701,52 @@ index 0000000000000000000000000000000000000000..00000000000000000000000000000000
*/
public interface OminousBottleMeta extends ItemMeta {
diff --git a/src/main/java/org/bukkit/inventory/meta/components/UseCooldownComponent.java b/src/main/java/org/bukkit/inventory/meta/components/UseCooldownComponent.java
index 0000000000000000000000000000000000000000..0000000000000000000000000000000000000000 100644
--- a/src/main/java/org/bukkit/inventory/meta/components/UseCooldownComponent.java
+++ b/src/main/java/org/bukkit/inventory/meta/components/UseCooldownComponent.java
@@ -0,0 +0,0 @@ import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.Nullable;
/**
- * Represents a component which determines the cooldown applied to use of this
- * item.
+ * Represents a component which determines the cooldown applied when using this item before it is available for use again.
*/
@ApiStatus.Experimental
public interface UseCooldownComponent extends ConfigurationSerializable {
/**
- * Gets the time in seconds it will take for this item to be eaten.
+ * Gets the time in seconds it will take for this item to be available for use again.
*
- * @return eat time
+ * @return cooldown time
*/
float getCooldownSeconds();
/**
- * Sets the time in seconds it will take for this item to be eaten.
+ * Sets the time in seconds it will take for this item to be available for use again.
*
* @param eatSeconds new eat time, must be positive
*/
- void setCooldownSeconds(float eatSeconds);
+ void setCooldownSeconds(float cooldownSeconds);
/**
* Gets the custom cooldown group to be used for similar items, if set.
@@ -0,0 +0,0 @@ public interface UseCooldownComponent extends ConfigurationSerializable {
/**
* Sets the custom cooldown group to be used for similar items.
*
- * @param song the cooldown group
+ * @param group the cooldown group
*/
- void setCooldownGroup(@Nullable NamespacedKey song);
+ void setCooldownGroup(@Nullable NamespacedKey group);
}
@@ -0,0 +0,0 @@ import org.jetbrains.annotations.ApiStatus;
*
- * @param eatSeconds new eat time, must be positive
+ * @param cooldownSeconds new cooldown time, must be positive
*/
diff --git a/src/main/java/org/bukkit/plugin/Plugin.java b/src/main/java/org/bukkit/plugin/Plugin.java
index 0000000000000000000000000000000000000000..0000000000000000000000000000000000000000 100644
--- a/src/main/java/org/bukkit/plugin/Plugin.java